==> nextcloud-25.0.6.tgz: nextcloud/lib/l10n/lt_LT.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nepavyksta rašyti į „config“ katalogą!",
    "See %s" : "Žiūrėkite %s",
    "Sample configuration detected" : "Aptiktas konfigūracijos pavyzdys",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Pastebėta, kad nukopijuota pavyzdinė konfigūracija. Tai gali pažeisti jūsų diegimą ir yra nepalaikoma. Prieš atliekant pakeitimus config.php faile, prašome perskaityti dokumentaciją.",
    "Other activities" : "Kitos veiklos",
    "%1$s and %2$s" : "%1$s ir %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s ir %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ir %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ir %5$s",
    "Groupware bundle" : "Grupinio darbo įrangos rinkinys",
    "PHP %s or higher is required." : "Reikalinga PHP %s arba aukštesnė.",
    "PHP with a version lower than %s is required." : "Reikalinga žemesnė nei %s PHP versija. ",
    "The command line tool %s could not be found" : "Nepavyko rasti komandų eilutės įrankio %s",
    "The library %s is not available." : "Biblioteka %s nėra prieinama.",
    "Server version %s or higher is required." : "Reikalinga %s arba aukštesnė serverio versija ",
    "Server version %s or lower is required." : "Reikalinga %s arba žemesnė serverio versija. ",
    "Logged in user must be an admin" : "Prisijungęs naudotojas privalo būti administratoriumi",
    "Wiping of device %s has started" : "Įrenginio %s duomenų ištrynimas pradėtas",
    "Wiping of device »%s« has started" : "Įrenginio »%s« duomenų ištrynimas pradėtas",
    "»%s« started remote wipe" : "»%s« pradėjo nuotolinių duomenų ištrynimą",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Įrenginys ar programa »%s« pradėjo nuotolinių duomenų ištrynimo procesą. Procesui užsibaigus, gausite dar vieną el. laišką",
    "Wiping of device %s has finished" : "Įrenginio %s duomenų ištrynimas užbaigtas",
    "Wiping of device »%s« has finished" : "Įrenginio »%s« duomenų ištrynimas užbaigtas",
    "»%s« finished remote wipe" : "»%s« užbaigė nuotolinių duomenų ištrynimą",
    "Device or application »%s« has finished the remote wipe process." : "Įrenginys ar programa »%s« užbaigė nuotolinių duomenų ištrynimo procesą.",
    "Remote wipe started" : "Nuotolinių duomenų ištrynimas pradėtas",
    "A remote wipe was started on device %s" : "Nuotolinių duomenų ištrynimas buvo pradėtas įrenginyje %s",
    "Remote wipe finished" : "Nuotolinių duomenų ištrynimas užbaigtas",
    "The remote wipe on %s has finished" : "Nuotolinių duomenų ištrynimas ties %s yra užbaigtas",
    "Authentication" : "Tapatybės nustatymas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "Invalid image" : "Neteisingas paveikslas",
    "Avatar image is not square" : "Avataro paveikslas nėra kvadratinis",
    "Files" : "Failai",
    "View profile" : "Rodyti profilį",
    "today" : "šiandien",
    "tomorrow" : "rytoj",
    "yesterday" : "vakar",
    "_in %n day_::_in %n days_" : ["po %n dienos","po %n dienų","po %n dienų","po %n dienos"],
    "_%n day ago_::_%n days ago_" : ["prieš %n dieną","prieš %n dienas","prieš %n dienų","prieš %n dieną"],
    "last month" : "praeitą mėnesį",
    "_in %n month_::_in %n months_" : ["po %n mėnesio","po %n mėnesių","po %n mėnesių","po %n mėnesio"],
    "_%n month ago_::_%n months ago_" : ["prieš %n mėnesį","prieš %n mėnesius","prieš %n mėnesių","prieš %n mėnesį"],
    "next year" : "kiti metai",
    "last year" : "praeitais metais",
    "_in %n year_::_in %n years_" : ["po %n metų","po %n metų","po %n metų","po %n metų"],
    "_%n year ago_::_%n years ago_" : ["prieš %n metus","prieš %n metus","prieš %n metų","prieš %n metus"],
    "_in %n hour_::_in %n hours_" : ["po %n valandos","po %n valandų","po %n valandų","po %n valandos"],
    "_%n hour ago_::_%n hours ago_" : ["prieš %n valandą","prieš %n valandas","prieš %n valandų","prieš %n valandą"],
    "_in %n minute_::_in %n minutes_" : ["po %n minutės","po %n minučių","po %n minučių","po %n minutės"],
    "_%n minute ago_::_%n minutes ago_" : ["prieš %n minutę","prieš %n minutes","prieš %n minučių","prieš %n minutę"],
    "in a few seconds" : "po kelių sekundžių",
    "seconds ago" : "prieš keletą sekundžių",
    "Empty file" : "Tuščias failas",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulio, kurio ID: %s, nėra. Prašome jį įjungti savo programėlių nustatymuose arba susisiekti su savo administratoriumi.",
    "File already exists" : "Failas jau yra",
    "Invalid path" : "Neteisingas kelias",
    "Templates" : "Šablonai",
    "File name is a reserved word" : "Failo pavadinimas negalimas, žodis rezervuotas",
    "File name contains at least one invalid character" : "Failo vardas sudarytas iš neleistinų simbolių",
    "File name is too long" : "Failo pavadinimas per ilgas",
    "Empty filename is not allowed" : "Tuščias failo pavadinimas nėra leidžiamas",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Programėlė „%s“ negali būti įdiegta, nes nepavyksta perskaityti appinfo failo.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Programėlė „%s“ negali būti įdiegta, nes ji nėra suderinama su šia serverio versija.",
    "__language_name__" : "Lietuvių",
    "This is an automatically sent email, please do not reply." : "Tai yra automatinis pranešimas, prašome neatsakyti.",
    "Help" : "Pagalba",
    "Appearance and accessibility" : "Išvaizda ir prieinamumas",
    "Apps" : "Programėlės",
    "Personal settings" : "Asmeniniai nustatymai",
    "Settings" : "Nustatymai",
    "Log out" : "Atsijungti",
    "Users" : "Naudotojai",
    "Email" : "El. paštas",
    "Mail %s" : "Rašyti laišką, adresu %s",
    "Phone" : "Telefonas",
    "Twitter" : "„Twitter“",
    "View %s on Twitter" : "Peržiūrėti %s puslapį „Twitter“ tinkle",
    "Website" : "Svetainė",
    "Visit %s" : "Apsilankyti, adresu %s",
    "Address" : "Adresas",
    "Profile picture" : "Profilio paveikslėlis",
    "About" : "Apie",
    "Headline" : "Antraštė",
    "Organisation" : "Organizacija",
    "Role" : "Vaidmuo",
    "Unknown user" : "Nežinomas naudotojas",
    "Additional settings" : "Papildomi nustatymai",
    "MySQL username and/or password not valid" : "Neteisingas MySQL naudotojo vardas ir/arba slaptažodis",
    "You need to enter details of an existing account." : "Jūs turite suvesti egzistuojančios paskyros duomenis.",
    "Oracle connection could not be established" : "Nepavyko užmegzti Oracle ryšio",
    "Oracle username and/or password not valid" : "Neteisingas Oracle naudotojo vardas ir/arba slaptažodis",
    "PostgreSQL username and/or password not valid" : "Neteisingas PostgreSQL naudotojo vardas ir/arba slaptažodis",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nėra palaikomas, %s neveiks tinkamai šioje platformoje. Naudodami prisiimate visą riziką !",
    "For the best results, please consider using a GNU/Linux server instead." : "Geriausiems rezultatams, apsvarstykite galimybę, vietoj šio, naudoti GNU/Linux serverį",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Pašalinkite savo php.ini faile open_basedir nustatymą arba persijunkite į 64-bitų PHP.",
    "Set an admin username." : "Nustatyti administratoriaus naudotojo vardą.",
    "Set an admin password." : "Nustatyti administratoriaus slaptažodį.",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s pasidalino „%2$s“ su jumis ir parašė pastabą:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s pasidalino „%2$s“ su jumis ir parašė pastabą",
    "»%s« added a note to a file shared with you" : "„%s“ parašė pastabą su jumis pasidalintam failui",
    "Open »%s«" : "Atverti \"%s\"",
    "%1$s via %2$s" : "%1$s per %2$s",
    "You are not allowed to share %s" : "Jums neleidžiama bendrinti %s",
    "Cannot increase permissions of %s" : "Negalima pridėti papildomų %s leidimų",
    "Expiration date is in the past" : "Bendrinimo pabaigos data yra praėjęs laikas",
    "Sharing %s failed, because this item is already shared with user %s" : "%s bendrinimas nepavyko, kadangi šis elementas jau yra bendrinamas su naudotoju %s",
    "%1$s shared »%2$s« with you" : "%1$s pasidalino „%2$s“ su jumis",
    "%1$s shared »%2$s« with you." : "%1$s pasidalino „%2$s“ su jumis.",
    "Click the button below to open it." : "Norėdami atverti failą, spustelėkite mygtuką žemiau.",
    "The requested share does not exist anymore" : "Pageidaujamas bendrinimas daugiau neegzistuoja.",
    "Could not find category \"%s\"" : "Nepavyko rasti kategorijos „%s“",
    "Sunday" : "Sekmadienis",
    "Monday" : "Pirmadienis",
    "Tuesday" : "Antradienis",
    "Wednesday" : "Trečiadienis",
    "Thursday" : "Ketvirtadienis",
    "Friday" : "Penktadienis",
    "Saturday" : "Šeštadienis",
    "Sun." : "Sek.",
    "Mon." : "Pir.",
    "Tue." : "Ant.",
    "Wed." : "Tre.",
    "Thu." : "Ket.",
    "Fri." : "Pen.",
    "Sat." : "Šeš.",
    "Su" : "Sk",
    "Mo" : "Pr",
    "Tu" : "An",
    "We" : "Tr",
    "Th" : "Kt",
    "Fr" : "Pn",
    "Sa" : "Št",
    "January" : "Sausis",
    "February" : "Vasaris",
    "March" : "Kovas",
    "April" : "Balandis",
    "May" : "Gegužė",
    "June" : "Birželis",
    "July" : "Liepa",
    "August" : "Rugpjūtis",
    "September" : "Rugsėjis",
    "October" : "Spalis",
    "November" : "Lapkritis",
    "December" : "Gruodis",
    "Jan." : "Sau.",
    "Feb." : "Vas.",
    "Mar." : "Kov.",
    "Apr." : "Bal.",
    "May." : "Geg.",
    "Jun." : "Bir.",
    "Jul." : "Lie.",
    "Aug." : "Rgp.",
    "Sep." : "Rgs.",
    "Oct." : "Spl.",
    "Nov." : "Lap.",
    "Dec." : "Grd.",
    "A valid password must be provided" : "Slaptažodis turi būti tinkamas",
    "The username is already being used" : "Naudotojo vardas jau yra naudojamas",
    "Could not create user" : "Nepavyko sukurti naudotojo",
    "A valid username must be provided" : "Privalo būti pateiktas tinkamas naudotojo vardas",
    "Username contains whitespace at the beginning or at the end" : "Naudotojo varde pradžioje ar pabaigoje yra tarpas",
    "Username must not consist of dots only" : "Naudotojo vardas negali būti sudarytas tik iš taškų.",
    "User disabled" : "Naudotojas išjungtas",
    "Login canceled by app" : "Programėlė nutraukė prisijungimo procesą",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Programėlė \"%1$s\" negali būti įdiegta, nes nėra patenkinamos šios priklausomybės: %2$s",
    "a safe home for all your data" : "saugūs namai visiems jūsų duomenims",
    "File is currently busy, please try again later" : "Failas šiuo metu yra užimtas, prašome vėliau pabandyti dar kartą",
    "Application is not enabled" : "Programa neįjungta",
    "Authentication error" : "Tapatybės nustatymo klaida",
    "Token expired. Please reload page." : "Pasibaigė prieigos rakto galiojimas. Prašome įkelti puslapį iš naujo.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nėra įdiegtos duomenų bazių tvarkyklės (sqlite, mysql, or postgresql)",
    "PHP module %s not installed." : "PHP modulis %s neįdiegtas.",
    "Please ask your server administrator to install the module." : "Kreipkitės į savo sistemos administratorių, kad jis įdiegtų modulį.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP nustatymas „%s“ nėra nustatytas į „%s“.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Šių nustatymų pritaikymas php.ini faile, iš naujo paleis Nextcloud",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Reikalinga ne mažesnė nei libxml2 2.7.0 versija. Šiuo metu yra instaliuota %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Atnaujinkite libxml2 versiją ir perkraukite žiniatinklio serverį, kad sutvarkytumėte šią problemą.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduliai yra įdiegti, bet jų vis tiek trūksta?",
    "Please ask your server administrator to restart the web server." : "Kreipkitės į savo sistemos administratorių, kad jis perkrautų žiniatinklio serverį.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Pakeiskite leidimus į 0770, kad šis katalogas negalėtų būti išvardytas kitiems naudotojams.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Įsitikinkite, kad šakniniame duomenų kataloge yra failas, pavadinimu „.ocdata“.",
    "Action \"%s\" not supported or implemented." : "Veiksmas \"%s\" nepalaikomas ar neįgyvendintas.",
    "Authentication failed, wrong token or provider ID given" : "Tapatybės nustatymas nepavyko, nurodytas neteisingas prieigos raktas arba teikėjo ID",
    "Could not obtain lock type %d on \"%s\"." : "Nepavyko gauti užrakto tipo %d ties „%s“.",
    "Storage unauthorized. %s" : "Saugykla nesankcionuota. %s",
    "Storage incomplete configuration. %s" : "Nepilna saugyklos konfigūracija. %s",
    "Storage connection error. %s" : "Saugyklos sujungimo ryšio klaida. %s",
    "Storage is temporarily not available" : "Saugykla yra laikinai neprieinama",
    "Storage connection timeout. %s" : "Sujungimo su saugykla laikas baigėsi. %s",
    "Full name" : "Vardas, pavardė",
    "%s enter the database username and name." : "%s įrašykite duomenų bazės naudotojo vardą ir pavadinimą.",
    "%s enter the database username." : "%s įrašykite duomenų bazės naudotojo vardą.",
    "%s enter the database name." : "%s įrašykite duomenų bazės pavadinimą.",
    "%s you may not use dots in the database name" : "%s negalite naudoti taškų duombazės pavadinime",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Naudotojo varde leidžiama naudoti tik šiuos simbolius: „a-z“, „A-Z“, „0-9“, ir „_.@-'“"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-25.0.7.tgz: nextcloud/lib/l10n/lt_LT.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nepavyksta rašyti į „config“ katalogą!",
    "See %s" : "Žiūrėkite %s",
    "Sample configuration detected" : "Aptiktas konfigūracijos pavyzdys",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Pastebėta, kad nukopijuota pavyzdinė konfigūracija. Tai gali pažeisti jūsų diegimą ir yra nepalaikoma. Prieš atliekant pakeitimus config.php faile, prašome perskaityti dokumentaciją.",
    "Other activities" : "Kitos veiklos",
    "%1$s and %2$s" : "%1$s ir %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s ir %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ir %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ir %5$s",
    "Groupware bundle" : "Grupinio darbo įrangos rinkinys",
    "PHP %s or higher is required." : "Reikalinga PHP %s arba aukštesnė.",
    "PHP with a version lower than %s is required." : "Reikalinga žemesnė nei %s PHP versija. ",
    "The command line tool %s could not be found" : "Nepavyko rasti komandų eilutės įrankio %s",
    "The library %s is not available." : "Biblioteka %s nėra prieinama.",
    "Server version %s or higher is required." : "Reikalinga %s arba aukštesnė serverio versija ",
    "Server version %s or lower is required." : "Reikalinga %s arba žemesnė serverio versija. ",
    "Logged in user must be an admin" : "Prisijungęs naudotojas privalo būti administratoriumi",
    "Wiping of device %s has started" : "Įrenginio %s duomenų ištrynimas pradėtas",
    "Wiping of device »%s« has started" : "Įrenginio »%s« duomenų ištrynimas pradėtas",
    "»%s« started remote wipe" : "»%s« pradėjo nuotolinių duomenų ištrynimą",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Įrenginys ar programa »%s« pradėjo nuotolinių duomenų ištrynimo procesą. Procesui užsibaigus, gausite dar vieną el. laišką",
    "Wiping of device %s has finished" : "Įrenginio %s duomenų ištrynimas užbaigtas",
    "Wiping of device »%s« has finished" : "Įrenginio »%s« duomenų ištrynimas užbaigtas",
    "»%s« finished remote wipe" : "»%s« užbaigė nuotolinių duomenų ištrynimą",
    "Device or application »%s« has finished the remote wipe process." : "Įrenginys ar programa »%s« užbaigė nuotolinių duomenų ištrynimo procesą.",
    "Remote wipe started" : "Nuotolinių duomenų ištrynimas pradėtas",
    "A remote wipe was started on device %s" : "Nuotolinių duomenų ištrynimas buvo pradėtas įrenginyje %s",
    "Remote wipe finished" : "Nuotolinių duomenų ištrynimas užbaigtas",
    "The remote wipe on %s has finished" : "Nuotolinių duomenų ištrynimas ties %s yra užbaigtas",
    "Authentication" : "Tapatybės nustatymas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "Invalid image" : "Neteisingas paveikslas",
    "Avatar image is not square" : "Avataro paveikslas nėra kvadratinis",
    "Files" : "Failai",
    "View profile" : "Rodyti profilį",
    "today" : "šiandien",
    "tomorrow" : "rytoj",
    "yesterday" : "vakar",
    "_in %n day_::_in %n days_" : ["po %n dienos","po %n dienų","po %n dienų","po %n dienos"],
    "_%n day ago_::_%n days ago_" : ["prieš %n dieną","prieš %n dienas","prieš %n dienų","prieš %n dieną"],
    "last month" : "praeitą mėnesį",
    "_in %n month_::_in %n months_" : ["po %n mėnesio","po %n mėnesių","po %n mėnesių","po %n mėnesio"],
    "_%n month ago_::_%n months ago_" : ["prieš %n mėnesį","prieš %n mėnesius","prieš %n mėnesių","prieš %n mėnesį"],
    "next year" : "kiti metai",
    "last year" : "praeitais metais",
    "_in %n year_::_in %n years_" : ["po %n metų","po %n metų","po %n metų","po %n metų"],
    "_%n year ago_::_%n years ago_" : ["prieš %n metus","prieš %n metus","prieš %n metų","prieš %n metus"],
    "_in %n hour_::_in %n hours_" : ["po %n valandos","po %n valandų","po %n valandų","po %n valandos"],
    "_%n hour ago_::_%n hours ago_" : ["prieš %n valandą","prieš %n valandas","prieš %n valandų","prieš %n valandą"],
    "_in %n minute_::_in %n minutes_" : ["po %n minutės","po %n minučių","po %n minučių","po %n minutės"],
    "_%n minute ago_::_%n minutes ago_" : ["prieš %n minutę","prieš %n minutes","prieš %n minučių","prieš %n minutę"],
    "in a few seconds" : "po kelių sekundžių",
    "seconds ago" : "prieš keletą sekundžių",
    "Empty file" : "Tuščias failas",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulio, kurio ID: %s, nėra. Prašome jį įjungti savo programėlių nustatymuose arba susisiekti su savo administratoriumi.",
    "File already exists" : "Failas jau yra",
    "Invalid path" : "Neteisingas kelias",
    "Templates" : "Šablonai",
    "File name is a reserved word" : "Failo pavadinimas negalimas, žodis rezervuotas",
    "File name contains at least one invalid character" : "Failo vardas sudarytas iš neleistinų simbolių",
    "File name is too long" : "Failo pavadinimas per ilgas",
    "Empty filename is not allowed" : "Tuščias failo pavadinimas nėra leidžiamas",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Programėlė „%s“ negali būti įdiegta, nes nepavyksta perskaityti appinfo failo.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Programėlė „%s“ negali būti įdiegta, nes ji nėra suderinama su šia serverio versija.",
    "__language_name__" : "Lietuvių",
    "This is an automatically sent email, please do not reply." : "Tai yra automatinis pranešimas, prašome neatsakyti.",
    "Help" : "Pagalba",
    "Appearance and accessibility" : "Išvaizda ir prieinamumas",
    "Apps" : "Programėlės",
    "Personal settings" : "Asmeniniai nustatymai",
    "Settings" : "Nustatymai",
    "Log out" : "Atsijungti",
    "Users" : "Naudotojai",
    "Email" : "El. paštas",
    "Mail %s" : "Rašyti laišką, adresu %s",
    "Phone" : "Telefonas",
    "Twitter" : "„Twitter“",
    "View %s on Twitter" : "Peržiūrėti %s puslapį „Twitter“ tinkle",
    "Website" : "Svetainė",
    "Visit %s" : "Apsilankyti, adresu %s",
    "Address" : "Adresas",
    "Profile picture" : "Profilio paveikslėlis",
    "About" : "Apie",
    "Headline" : "Antraštė",
    "Organisation" : "Organizacija",
    "Role" : "Vaidmuo",
    "Unknown user" : "Nežinomas naudotojas",
    "Additional settings" : "Papildomi nustatymai",
    "MySQL username and/or password not valid" : "Neteisingas MySQL naudotojo vardas ir/arba slaptažodis",
    "You need to enter details of an existing account." : "Jūs turite suvesti egzistuojančios paskyros duomenis.",
    "Oracle connection could not be established" : "Nepavyko užmegzti Oracle ryšio",
    "Oracle username and/or password not valid" : "Neteisingas Oracle naudotojo vardas ir/arba slaptažodis",
    "PostgreSQL username and/or password not valid" : "Neteisingas PostgreSQL naudotojo vardas ir/arba slaptažodis",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nėra palaikomas, %s neveiks tinkamai šioje platformoje. Naudodami prisiimate visą riziką !",
    "For the best results, please consider using a GNU/Linux server instead." : "Geriausiems rezultatams, apsvarstykite galimybę, vietoj šio, naudoti GNU/Linux serverį",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Pašalinkite savo php.ini faile open_basedir nustatymą arba persijunkite į 64-bitų PHP.",
    "Set an admin username." : "Nustatyti administratoriaus naudotojo vardą.",
    "Set an admin password." : "Nustatyti administratoriaus slaptažodį.",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s pasidalino „%2$s“ su jumis ir parašė pastabą:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s pasidalino „%2$s“ su jumis ir parašė pastabą",
    "»%s« added a note to a file shared with you" : "„%s“ parašė pastabą su jumis pasidalintam failui",
    "Open »%s«" : "Atverti \"%s\"",
    "%1$s via %2$s" : "%1$s per %2$s",
    "You are not allowed to share %s" : "Jums neleidžiama bendrinti %s",
    "Cannot increase permissions of %s" : "Negalima pridėti papildomų %s leidimų",
    "Expiration date is in the past" : "Bendrinimo pabaigos data yra praėjęs laikas",
    "Sharing %s failed, because this item is already shared with user %s" : "%s bendrinimas nepavyko, kadangi šis elementas jau yra bendrinamas su naudotoju %s",
    "%1$s shared »%2$s« with you" : "%1$s pasidalino „%2$s“ su jumis",
    "%1$s shared »%2$s« with you." : "%1$s pasidalino „%2$s“ su jumis.",
    "Click the button below to open it." : "Norėdami atverti failą, spustelėkite mygtuką žemiau.",
    "The requested share does not exist anymore" : "Pageidaujamas bendrinimas daugiau neegzistuoja.",
    "Could not find category \"%s\"" : "Nepavyko rasti kategorijos „%s“",
    "Sunday" : "Sekmadienis",
    "Monday" : "Pirmadienis",
    "Tuesday" : "Antradienis",
    "Wednesday" : "Trečiadienis",
    "Thursday" : "Ketvirtadienis",
    "Friday" : "Penktadienis",
    "Saturday" : "Šeštadienis",
    "Sun." : "Sek.",
    "Mon." : "Pir.",
    "Tue." : "Ant.",
    "Wed." : "Tre.",
    "Thu." : "Ket.",
    "Fri." : "Pen.",
    "Sat." : "Šeš.",
    "Su" : "Sk",
    "Mo" : "Pr",
    "Tu" : "An",
    "We" : "Tr",
    "Th" : "Kt",
    "Fr" : "Pn",
    "Sa" : "Št",
    "January" : "Sausis",
    "February" : "Vasaris",
    "March" : "Kovas",
    "April" : "Balandis",
    "May" : "Gegužė",
    "June" : "Birželis",
    "July" : "Liepa",
    "August" : "Rugpjūtis",
    "September" : "Rugsėjis",
    "October" : "Spalis",
    "November" : "Lapkritis",
    "December" : "Gruodis",
    "Jan." : "Sau.",
    "Feb." : "Vas.",
    "Mar." : "Kov.",
    "Apr." : "Bal.",
    "May." : "Geg.",
    "Jun." : "Bir.",
    "Jul." : "Lie.",
    "Aug." : "Rgp.",
    "Sep." : "Rgs.",
    "Oct." : "Spl.",
    "Nov." : "Lap.",
    "Dec." : "Grd.",
    "A valid password must be provided" : "Slaptažodis turi būti tinkamas",
    "The username is already being used" : "Naudotojo vardas jau yra naudojamas",
    "Could not create user" : "Nepavyko sukurti naudotojo",
    "A valid username must be provided" : "Privalo būti pateiktas tinkamas naudotojo vardas",
    "Username contains whitespace at the beginning or at the end" : "Naudotojo varde pradžioje ar pabaigoje yra tarpas",
    "Username must not consist of dots only" : "Naudotojo vardas negali būti sudarytas tik iš taškų.",
    "User disabled" : "Naudotojas išjungtas",
    "Login canceled by app" : "Programėlė nutraukė prisijungimo procesą",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Programėlė \"%1$s\" negali būti įdiegta, nes nėra patenkinamos šios priklausomybės: %2$s",
    "a safe home for all your data" : "saugūs namai visiems jūsų duomenims",
    "File is currently busy, please try again later" : "Failas šiuo metu yra užimtas, prašome vėliau pabandyti dar kartą",
    "Application is not enabled" : "Programa neįjungta",
    "Authentication error" : "Tapatybės nustatymo klaida",
    "Token expired. Please reload page." : "Pasibaigė prieigos rakto galiojimas. Prašome įkelti puslapį iš naujo.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nėra įdiegtos duomenų bazių tvarkyklės (sqlite, mysql, or postgresql)",
    "PHP module %s not installed." : "PHP modulis %s neįdiegtas.",
    "Please ask your server administrator to install the module." : "Kreipkitės į savo sistemos administratorių, kad jis įdiegtų modulį.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP nustatymas „%s“ nėra nustatytas į „%s“.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Šių nustatymų pritaikymas php.ini faile, iš naujo paleis Nextcloud",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduliai yra įdiegti, bet jų vis tiek trūksta?",
    "Please ask your server administrator to restart the web server." : "Kreipkitės į savo sistemos administratorių, kad jis perkrautų žiniatinklio serverį.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Pakeiskite leidimus į 0770, kad šis katalogas negalėtų būti išvardytas kitiems naudotojams.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Įsitikinkite, kad šakniniame duomenų kataloge yra failas, pavadinimu „.ocdata“.",
    "Action \"%s\" not supported or implemented." : "Veiksmas \"%s\" nepalaikomas ar neįgyvendintas.",
    "Authentication failed, wrong token or provider ID given" : "Tapatybės nustatymas nepavyko, nurodytas neteisingas prieigos raktas arba teikėjo ID",
    "Could not obtain lock type %d on \"%s\"." : "Nepavyko gauti užrakto tipo %d ties „%s“.",
    "Storage unauthorized. %s" : "Saugykla nesankcionuota. %s",
    "Storage incomplete configuration. %s" : "Nepilna saugyklos konfigūracija. %s",
    "Storage connection error. %s" : "Saugyklos sujungimo ryšio klaida. %s",
    "Storage is temporarily not available" : "Saugykla yra laikinai neprieinama",
    "Storage connection timeout. %s" : "Sujungimo su saugykla laikas baigėsi. %s",
    "Full name" : "Vardas, pavardė",
    "%s enter the database username and name." : "%s įrašykite duomenų bazės naudotojo vardą ir pavadinimą.",
    "%s enter the database username." : "%s įrašykite duomenų bazės naudotojo vardą.",
    "%s enter the database name." : "%s įrašykite duomenų bazės pavadinimą.",
    "%s you may not use dots in the database name" : "%s negalite naudoti taškų duombazės pavadinime",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Naudotojo varde leidžiama naudoti tik šiuos simbolius: „a-z“, „A-Z“, „0-9“, ir „_.@-'“",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Reikalinga ne mažesnė nei libxml2 2.7.0 versija. Šiuo metu yra instaliuota %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Atnaujinkite libxml2 versiją ir perkraukite žiniatinklio serverį, kad sutvarkytumėte šią problemą."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
